import { default as React } from 'react';
import { UseFloatingOptions } from '@floating-ui/react';

/**
 * Fully managed floating content function.
 */
export type Managed<T = React.ReactElement | React.ReactNode> = (show: () => void, hide: () => void) => T;
/**
 * Allowed floating modes.
 */
export type FloatingMode = "always" | "click" | "hover" | "focus" | "managed";
/**
 * Role of a floating element.
 */
export type FloatRole = "tooltip" | "dialog" | "alertdialog" | "menu" | "listbox" | "grid" | "tree" | "select" | "label" | "combobox";
/**
 * Type of the element on which the floating element is based.
 */
export type FloatChild = (React.ReactElement & React.ClassAttributes<HTMLElement>) | Managed<(React.ReactElement & React.ClassAttributes<HTMLElement>)>;
/**
 * Properties of the Float component.
 */
export interface FloatProperties {
    children: FloatChild;
    content?: React.ReactNode | Managed<React.ReactNode>;
    className?: string;
    mode?: FloatingMode;
    dismissible?: boolean;
    role?: FloatRole;
    floatingOptions?: UseFloatingOptions;
}
/**
 * A component to show something floating next to an element.
 */
export declare const Float: React.ForwardRefExoticComponent<FloatProperties & React.RefAttributes<unknown>>;
