import { default as React } from 'react';

/**
 * Notification UUID type.
 */
export type NotificationUuid = string;
/**
 * Notification data.
 */
export interface NotificationData {
    /**
     * The notification content.
     */
    content: React.ReactNode;
}
/**
 * Type of notification emitter function.
 */
export type EmitNotificationFunction = (content: React.ReactNode) => void;
/**
 * Type of notification close function.
 */
export type RemoveNotificationFunction = (uuid: NotificationUuid) => void;
/**
 * Type of notification close function.
 */
export type CloseNotificationFunction = (uuid: NotificationUuid) => void;
/**
 * Type of notification closed state function.
 */
export type IsNotificationClosedFunction = (uuid: NotificationUuid) => boolean;
/**
 * Interface of notifications state.
 */
export interface NotificationsContextState {
    /**
     * Notification function.
     * @param content Notification content.
     */
    notify: EmitNotificationFunction;
    /**
     * Close notification function.
     * @param uuid UUID of notification to close.
     */
    close: CloseNotificationFunction;
    /**
     * Is given notification closed?
     * @param uuid UUID of notification to get closed state.
     */
    isClosed: IsNotificationClosedFunction;
}
export declare const NotificationsContext: React.Context<NotificationsContextState>;
/**
 * Hook to emit a notification.
 */
export declare function useNotify(): EmitNotificationFunction;
/**
 * Notifications provider.
 */
export declare function NotificationsProvider({ children }: React.PropsWithChildren<{}>): React.JSX.Element;
/**
 * A notification context.
 */
export declare const NotificationContext: React.Context<{
    /**
     * Notification UUID.
     */
    uuid: NotificationUuid;
    /**
     * Notification closed state.
     */
    closed: boolean;
}>;
